/**********************************************************************************
 *    EasyPCA performs a PCA analysis of a binary input file                      *
 *    Copyright (C) 2008  Javier Cruz Mota                                        *
 *    E-Mail: javier.cruz (AT) epfl.ch                                            *
 *    Postal Address: EPFL /  ENAC /  INTER /  TRANSP-OR                          *
 *                    GC B3 425 (Bâtiment GC), Station 18                         *
 *                    CH-1015 Lausanne (Switzerland)                              *
 *                                                                                *
 *    This file is part of EasyPCA.                                               * 
 *                                                                                *
 *    EasyPCA is free software; you can redistribute it and/or modify             *
 *    it under the terms of the GNU General Public License as published by        *
 *    the Free Software Foundation; either version 2 of the License, or           *
 *    (at your option) any later version.                                         *
 *                                                                                *
 *    EasyPCA is distributed in the hope that it will be useful,                  *
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 *    GNU General Public License for more details.                                *
 *                                                                                *
 *    You should have received a copy of the GNU General Public License           *
 *    along with EasyPCA; if not, write to the Free Software                      *
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA  *
 **********************************************************************************/


#include "pca.hpp"

int main(int argc, char *argv[])
{
	if (argc!=4)
	{
		std::cerr << "Usage: " << argv[0] << " FileIn EnergyPerCent FileOut" << std::endl << std::endl;
		std::cerr << "\t\tFileIn: Binary input file (see README for details)" << std::endl;
		std::cerr << "\t\tEnergyPerCent: Energy amount to be selected (typically 0.98)" << std::endl;
		std::cerr << "\t\tFileOut: Binary output file (see README for details)" << std::endl;
		return ERROR;
	}
	std::string fileIn, fileOut;
	fileIn.assign(argv[1]);
	fileOut.assign(argv[3]);
	
	float selEnergy = atof(argv[2]);
	
	PCA myPCA;
	try{
		std::cout << "Loading Matrix...";
		std::cout.flush();
		myPCA.PCA_LoadMatrix(fileIn.c_str());
		//myPCA.PCA_LoadMatrix();
		std::cout << "Done!" << std::endl;
		std::cout << "Performing PCA..." << std::endl;
		myPCA.PCA_PerformPCA();
		std::cout << "Done!" << std::endl;
		myPCA.PCA_SelectSubset(selEnergy,myPCA.PCA_GetIsTransposed());
		myPCA.PCA_WriteResult(fileOut.c_str());
		myPCA.PCA_PrintResult();
	}catch(std::string PCAexception)
	{
		std::cerr << "Exception received: " << PCAexception << std::endl;
		std::cerr << "Exiting!" << std::endl;
	}

	return NOERROR;
}
